/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify OAI-PMH Model - OAIMetadataPrefix.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.model.oai;

import java.net.URL;
import java.util.Objects;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Lob;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import ch.unige.solidify.OAIConstants;
import ch.unige.solidify.SolidifyConstants;
import ch.unige.solidify.rest.ResourceNormalized;

@Entity
@Table(name = "oaiMetadataPrefix")
public class OAIMetadataPrefix extends ResourceNormalized {

  private static final int DB_METADATA_LENGTH = 102400;

  @NotNull
  @Size(min = 1)
  @Column(unique = true)
  private String prefix;

  @NotNull
  private URL schemaUrl;

  @NotNull
  private String schemaNamespace;

  @NotNull
  @Size(min = 1)
  @Column(unique = true)
  private String name;

  @Size(min = 1, max = SolidifyConstants.DB_LONG_STRING_LENGTH)
  private String description;

  @NotNull
  private Boolean enabled;

  @NotNull
  private Boolean reference;

  @Lob
  @Size(max = DB_METADATA_LENGTH) // Set column size (100KB) for H2 & documentation
  private String metadataSchema;

  @Lob
  @Size(max = DB_METADATA_LENGTH) // Set column size (100KB) for H2 & documentation
  private String metadataXmlTransformation;

  public String getDescription() {
    return this.description;
  }

  public String getName() {
    return this.name;
  }

  public String getPrefix() {
    return this.prefix;
  }

  public URL getSchemaUrl() {
    return schemaUrl;
  }

  public String getSchemaNamespace() {
    return schemaNamespace;
  }

  public Boolean getEnabled() {
    return this.enabled;
  }

  public Boolean getReference() {
    return reference;
  }

  public String getMetadataSchema() {
    return this.metadataSchema;
  }

  public String getMetadataXmlTransformation() {
    return this.metadataXmlTransformation;
  }

  @Override
  @PrePersist
  @PreUpdate
  public void init() {
    if (this.enabled == null) {
      this.enabled = false;
    }
    if (this.reference == null) {
      this.reference = false;
    }
  }

  public boolean isEnabled() {
    return Objects.requireNonNullElse(this.enabled, Boolean.FALSE);
  }

  public boolean isReference() {
    return Objects.requireNonNullElse(this.reference, Boolean.FALSE);
  }

  @Override
  public String managedBy() {
    return OAIConstants.OAI_MODULE;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public void setEnabled(Boolean enabled) {
    this.enabled = enabled;
  }

  public void setReference(Boolean reference) {
    this.reference = reference;
  }

  public void setName(String name) {
    this.name = name;
  }

  public void setPrefix(String prefix) {
    this.prefix = prefix;
  }

  public void setMetadataSchema(String metadataSchema) {
    this.metadataSchema = metadataSchema;
  }

  public void setMetadataXmlTransformation(String metadataXmlTransformation) {
    this.metadataXmlTransformation = metadataXmlTransformation;
  }

  public void setSchemaUrl(URL schemaUrl) {
    this.schemaUrl = schemaUrl;
  }

  public void setSchemaNamespace(String schemaNamespace) {
    this.schemaNamespace = schemaNamespace;
  }

}
